<?php

/**
 * Return a themed breadcrumb trail.
 *
 * @param $breadcrumb
 *   An array containing the breadcrumb links.
 * @return
 *   A string containing the breadcrumb output.
 */
function portfolioplus_breadcrumb($variables){

  $breadcrumb = $variables['breadcrumb'];
  $breadcrumb_separator=theme_get_setting('breadcrumb_separator');

  if (!empty($breadcrumb)) {
  $breadcrumb[] = drupal_get_title();
  return '<div>' . implode(' <span class="breadcrumb-separator">' . $breadcrumb_separator . '</span>', $breadcrumb) . '</div>';
  }

}

/**
 * Add classes to block.
 */
function portfolioplus_preprocess_block(&$variables) {

  $variables['title_attributes_array']['class'][] = 'title';
  $variables['classes_array'][]='clearfix';

}

/**
 * Override or insert variables into the html template.
 */
function portfolioplus_preprocess_html(&$variables) {

  if (empty($variables['page']['banner'])) {
    $variables['classes_array'][] = 'no-banner';
  }

  $color_scheme = theme_get_setting('color_scheme');

  if ($color_scheme != 'default') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/style-' .$color_scheme. '.css', array('group' => CSS_THEME, 'type' => 'file'));
  }

  if (isset($_SERVER['HTTPS']) && strtolower($_SERVER['HTTPS']) == 'on') {
    $protocol = "/https";
  } else {
    $protocol = "/http";
  }

  if (theme_get_setting('sitename_font_family')=='sff-1'  &&
    theme_get_setting('slogan_font_family')=='slff-1' ||
    theme_get_setting('headings_font_family')=='hff-1' ||
    theme_get_setting('paragraph_font_family')=='pff-1') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/merriweather-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-2'  ||
    theme_get_setting('slogan_font_family')=='slff-2' ||
    theme_get_setting('headings_font_family')=='hff-2' ||
    theme_get_setting('paragraph_font_family')=='pff-2') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/sourcesanspro-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-3'  ||
    theme_get_setting('slogan_font_family')=='slff-3' ||
    theme_get_setting('headings_font_family')=='hff-3' ||
    theme_get_setting('paragraph_font_family')=='pff-3') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/ubuntu-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-4'  ||
    theme_get_setting('slogan_font_family')=='slff-4' ||
    theme_get_setting('headings_font_family')=='hff-4' ||
    theme_get_setting('paragraph_font_family')=='pff-4') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/ptsans-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-5'  ||
    theme_get_setting('slogan_font_family')=='slff-5' ||
    theme_get_setting('headings_font_family')=='hff-5' ||
    theme_get_setting('paragraph_font_family')=='pff-5') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/roboto-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-6'  ||
    theme_get_setting('slogan_font_family')=='slff-6' ||
    theme_get_setting('headings_font_family')=='hff-6' ||
    theme_get_setting('paragraph_font_family')=='pff-6') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/opensans-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-7'  ||
    theme_get_setting('slogan_font_family')=='slff-7' ||
    theme_get_setting('headings_font_family')=='hff-7' ||
    theme_get_setting('paragraph_font_family')=='pff-7') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/lato-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-8'  ||
    theme_get_setting('slogan_font_family')=='slff-8' ||
    theme_get_setting('headings_font_family')=='hff-8' ||
    theme_get_setting('paragraph_font_family')=='pff-8') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/roboto-condensed-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-9'  ||
    theme_get_setting('slogan_font_family')=='slff-9' ||
    theme_get_setting('headings_font_family')=='hff-9' ||
    theme_get_setting('paragraph_font_family')=='pff-9') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/exo-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-10'  ||
    theme_get_setting('slogan_font_family')=='slff-10' ||
    theme_get_setting('headings_font_family')=='hff-10' ||
    theme_get_setting('paragraph_font_family')=='pff-10') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/roboto-slab-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-11'  ||
    theme_get_setting('slogan_font_family')=='slff-11' ||
    theme_get_setting('headings_font_family')=='hff-11' ||
    theme_get_setting('paragraph_font_family')=='pff-11') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/raleway-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-12'  ||
    theme_get_setting('slogan_font_family')=='slff-12' ||
    theme_get_setting('headings_font_family')=='hff-12' ||
    theme_get_setting('paragraph_font_family')=='pff-12') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/josefin-sans-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-14'  ||
    theme_get_setting('slogan_font_family')=='slff-14' ||
    theme_get_setting('headings_font_family')=='hff-14' ||
    theme_get_setting('paragraph_font_family')=='pff-14') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/playfair-display-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-15'  ||
    theme_get_setting('slogan_font_family')=='slff-15' ||
    theme_get_setting('headings_font_family')=='hff-15' ||
    theme_get_setting('paragraph_font_family')=='pff-15') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/philosopher-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-16'  ||
    theme_get_setting('slogan_font_family')=='slff-16' ||
    theme_get_setting('headings_font_family')=='hff-16') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/cinzel-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-17'  ||
    theme_get_setting('slogan_font_family')=='slff-17' ||
    theme_get_setting('headings_font_family')=='hff-17' ||
    theme_get_setting('paragraph_font_family')=='pff-16') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/oswald-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-18'  ||
    theme_get_setting('slogan_font_family')=='slff-18' ||
    theme_get_setting('headings_font_family')=='hff-18' ||
    theme_get_setting('paragraph_font_family')=='pff-17') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/playfairdisplaysc-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-19'  ||
    theme_get_setting('slogan_font_family')=='slff-19' ||
    theme_get_setting('headings_font_family')=='hff-19' ||
    theme_get_setting('paragraph_font_family')=='pff-18') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/cabin-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-20'  ||
    theme_get_setting('slogan_font_family')=='slff-20' ||
    theme_get_setting('headings_font_family')=='hff-20' ||
    theme_get_setting('paragraph_font_family')=='pff-19') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/notosans-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-22'  ||
    theme_get_setting('slogan_font_family')=='slff-22' ||
    theme_get_setting('headings_font_family')=='hff-22' ||
    theme_get_setting('paragraph_font_family')=='pff-21') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/droidserif-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-23'  ||
    theme_get_setting('slogan_font_family')=='slff-23' ||
    theme_get_setting('headings_font_family')=='hff-23' ||
    theme_get_setting('paragraph_font_family')=='pff-22') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/ptserif-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-24'  ||
    theme_get_setting('slogan_font_family')=='slff-24' ||
    theme_get_setting('headings_font_family')=='hff-24' ||
    theme_get_setting('paragraph_font_family')=='pff-23') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/vollkorn-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-25'  ||
    theme_get_setting('slogan_font_family')=='slff-25' ||
    theme_get_setting('headings_font_family')=='hff-25' ||
    theme_get_setting('paragraph_font_family')=='pff-24') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/alegreya-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-26'  ||
    theme_get_setting('slogan_font_family')=='slff-26' ||
    theme_get_setting('headings_font_family')=='hff-26' ||
    theme_get_setting('paragraph_font_family')=='pff-25') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/notoserif-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-27'  ||
    theme_get_setting('slogan_font_family')=='slff-27' ||
    theme_get_setting('headings_font_family')=='hff-27' ||
    theme_get_setting('paragraph_font_family')=='pff-26') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/crimsontext-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-28'  ||
    theme_get_setting('slogan_font_family')=='slff-28' ||
    theme_get_setting('headings_font_family')=='hff-28' ||
    theme_get_setting('paragraph_font_family')=='pff-27') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/gentiumbookbasic-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-29'  ||
    theme_get_setting('slogan_font_family')=='slff-29' ||
    theme_get_setting('headings_font_family')=='hff-29' ||
    theme_get_setting('paragraph_font_family')=='pff-28') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/volkhov-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-31'  ||
    theme_get_setting('slogan_font_family')=='slff-31' ||
    theme_get_setting('headings_font_family')=='hff-31') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts'.$protocol. '/alegreyasc-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-32'  ||
    theme_get_setting('slogan_font_family')=='slff-32' ||
    theme_get_setting('headings_font_family')=='hff-32') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts' .$protocol. '/montserrat-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-33'  ||
    theme_get_setting('slogan_font_family')=='slff-33' ||
    theme_get_setting('headings_font_family')=='hff-33' ||
    theme_get_setting('paragraph_font_family')=='pff-30') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts' .$protocol. '/firasans-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-34'  ||
    theme_get_setting('slogan_font_family')=='slff-34' ||
    theme_get_setting('headings_font_family')=='hff-34' ||
    theme_get_setting('paragraph_font_family')=='pff-31') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts' .$protocol. '/lora-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('sitename_font_family')=='sff-35'  ||
    theme_get_setting('slogan_font_family')=='slff-35' ||
    theme_get_setting('headings_font_family')=='hff-35' ||
    theme_get_setting('paragraph_font_family')=='pff-32') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts' .$protocol. '/firasans-moz-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('monospaced_font_family')=='mff-1') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts' .$protocol. '/sourcecodepro-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('monospaced_font_family')=='mff-2') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts' .$protocol. '/firamono-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('monospaced_font_family')=='mff-3') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts' .$protocol. '/robotomono-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (theme_get_setting('monospaced_font_family')=='mff-4') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts' .$protocol. '/cutivemono-font.css', array('group' => CSS_THEME, 'type' => 'file' , 'preprocess' => FALSE));
  }

  if (isset($_SERVER['HTTPS']) && strtolower($_SERVER['HTTPS']) == 'on') {
    drupal_add_css('https://netdna.bootstrapcdn.com/font-awesome/4.3.0/css/font-awesome.css', array('type' => 'external'));
  } else {
    drupal_add_css('http://netdna.bootstrapcdn.com/font-awesome/4.3.0/css/font-awesome.css', array('type' => 'external'));
  }

  drupal_add_css(path_to_theme() . '/ie9.css', array('group' => CSS_THEME, 'browsers' => array('IE' => '(IE 9)&(!IEMobile)', '!IE' => FALSE), 'preprocess' => FALSE));

  /**
   * Add local.css file for CSS overrides.
   */
  drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/local.css', array('group' => CSS_THEME, 'type' => 'file'));

  /**
  * Add Javascript for enable/disable Bootstrap 3 Javascript.
  */
  if (theme_get_setting('bootstrap_js_include')) {
  drupal_add_js(drupal_get_path('theme', 'portfolioplus') . '/bootstrap/js/bootstrap.min.js');
  }
  //EOF:Javascript

  /**
   * Add Javascript for enable/disable scrollTop action.
   */
  if (theme_get_setting('scrolltop_display')) {

    drupal_add_js('jQuery(document).ready(function($) {
    $(window).scroll(function() {
      if($(this).scrollTop() != 0) {
        $("#toTop").fadeIn();
      } else {
        $("#toTop").fadeOut();
      }
    });

    $("#toTop").click(function() {
      $("body,html").animate({scrollTop:0},800);
    });

    });',
    array('type' => 'inline', 'scope' => 'header'));

  }

    /**
  * Add Javascript for enable/disable Isotope Javascript.
  */
  if (theme_get_setting('isotope_js_include')) {

  drupal_add_js(drupal_get_path('theme', 'portfolioplus') .'/js/isotope/jquery.isotope.js', array('preprocess' => false));
  drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/js/isotope/jquery.isotope.css');

  drupal_add_js('
    jQuery(document).ready(function($) {

      $(window).load(function() {

        $(".filters").fadeIn("slow");
        $(".filter-items").fadeIn("slow");
        var container = $(".filter-items"),
        filters= $(".filters");

        container.isotope({
            itemSelector: ".isotope-item",
            layoutMode : "sloppyMasonry",
            filter: "*"
        });

    $(".filters").prepend( "<li class=\"active\"><a href=\"#\" data-filter=\"*\">All</a></li>" );
        filters.find("a").click(function(){
            var $this = $(this);
            var selector = $this.attr("data-filter").replace(/\s+/g, "-");

            filters.find("li.active").removeClass("active");
            $this.parent().addClass("active");

            container.isotope({ filter: selector });
            return false;
        });


      });

    });',array('type' => 'inline', 'scope' => 'footer', 'weight' => 2)
  );
  }
  //EOF:Javascript

  /**
   * Add Javascript for Fixed Header
   */
  $fixed_header = theme_get_setting('fixed_header');
  if ($fixed_header) {


    drupal_add_js('jQuery(document).ready(function($) {

      var headerTopHeight = $("#header-top").outerHeight(),
      navItemHeight =  $("#main-navigation ul.menu li a").outerHeight(),
      navHeight =  $("#main-navigation").outerHeight(),
      toolbarHeight =  $("#toolbar").outerHeight(),
      headerHeight = $("#header").outerHeight();

      if ($("#toolbar").length>0) {
        var toolbarHeight =  $("#toolbar").outerHeight();
      } else {
        var toolbarHeight =  0;
      }

      // fix for Chrome
      if (navHeight > navItemHeight*2) {
        headerHeight = headerHeight - navItemHeight;
      };

      $(".logged-in .tabs.primary a, .logged-in .contextual-links a").click(function() {
        $("body").removeClass("onscroll");
        $("#header-container").css("paddingBottom", (0)+"px");
        $("#header").css("top", (0)+"px");
      });

      $(window).load(function() {
        if(($(window).width() > 767)) {
          $("body").addClass("fixed-header-enabled");
        } else {
          $("body").removeClass("fixed-header-enabled");
        }
      });

      $(window).resize(function() {
        if(($(window).width() > 767)) {
          $("body").addClass("fixed-header-enabled");
        } else {
          $("body").removeClass("fixed-header-enabled");
        }
      });

      $(window).scroll(function() {
        if (!(($(".transparent-header-active").length>0) && ($("#banner #slideshow-fullscreen").length>0))) {
          if (($(this).scrollTop() > headerTopHeight+headerHeight) && ($(window).width() > 767)) {
            $("body").addClass("onscroll");
            $("#header-container").css("paddingBottom", (headerHeight)+"px");
            $("#header").css("top", (toolbarHeight)+"px");
          } else {
            $("body").removeClass("onscroll");
            $("#header-container").css("paddingBottom", (0)+"px");
            $("#header").css("top", (0)+"px");
          }
        } else {
          if (($(this).scrollTop() > headerTopHeight+headerHeight) && ($(window).width() > 767)) {
            $("body").addClass("onscroll");
            $("#header").css("top", (toolbarHeight)+"px");
          } else {
            $("body").removeClass("onscroll");
            $("#header").css("top", (0)+"px");
          }

        };
      });
    });',
    array('type' => 'inline', 'scope' => 'header'));
    //EOF:Javascript

  }



  /**
   * Mobile Menu
   */
  $responsive_meanmenu = theme_get_setting('responsive_multilevelmenu_state');

  if ($responsive_meanmenu) {

  drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/js/meanmenu/meanmenu.css');
  drupal_add_js(drupal_get_path('theme', 'portfolioplus') .'/js/meanmenu/jquery.meanmenu.fork.js', array('preprocess' => false));

    /**
     * Add Javascript for Mobile Menu
     */
    drupal_add_js('jQuery(document).ready(function($) {

      $("#main-navigation .sf-menu, #main-navigation .content>ul.menu, #main-navigation ul.main-menu").wrap("<div class=\'meanmenu-wrapper\'></div>");
      $("#main-navigation .meanmenu-wrapper").meanmenu({
        meanScreenWidth: "767",
        meanRemoveAttrs: true,
        meanMenuContainer: "#header-inside",
        meanMenuClose: ""
      });

      $("#header-top .sf-menu, #header-top .content>ul.menu").wrap("<div class=\'header-top-meanmenu-wrapper\'></div>");
      $("#header-top .header-top-meanmenu-wrapper").meanmenu({
        meanScreenWidth: "767",
        meanRemoveAttrs: true,
        meanMenuContainer: "#header-top-inside",
        meanMenuClose: ""
      });

    });',
    array('type' => 'inline', 'scope' => 'header'));
    //EOF:Javascript

  }

  /**
   * Add Javascript for testimonial slider.
   */
  $testimonial_effect=theme_get_setting('testimonial_slideshow_effect');
  $testimonial_effect_time=theme_get_setting('testimonial_slideshow_effect_time')*1000;

  drupal_add_js('
    jQuery(document).ready(function($) {
    if ($("div").hasClass("view-testimonials-slider")){

      $(window).load(function() {
      $(".view-testimonials .flexslider").fadeIn("slow");
      $(".view-testimonials .flexslider").flexslider({
      animation: "'.$testimonial_effect.'",
      slideshowSpeed: '.$testimonial_effect_time.',
      useCSS: false,
      prevText: "",
        nextText: ""
      });
      });
    }
    });',array('type' => 'inline', 'scope' => 'footer', 'weight' => 2)
  );
  //EOF:Javascript

  $variables['classes_array'][] = 'parallax-active';
  $parallax_opacity = (int) theme_get_setting('parallax_opacity')/100;

  /**
   * Add Javascript
   */
  drupal_add_js('jQuery(document).ready(function($) {

    $(window).load(function() {
      $("#media-background-parallax-transparency").css("backgroundColor", "rgba(0,0,0,'.$parallax_opacity.')");
    });

  });',
  array('type' => 'inline', 'scope' => 'header'));
  //EOF:Javascript




  /**
 * Add Javascript for Google Map
 */
  if (theme_get_setting('google_map_js', 'portfolioplus')) {

    drupal_add_js('jQuery(document).ready(function($) {

      var map;
      var myLatlng;
      var myZoom;
      var marker;

    });',
    array('type' => 'inline', 'scope' => 'header')
    );

    drupal_add_js('https://maps.googleapis.com/maps/api/js?v=3.exp&sensor=false',
    array('type' => 'external', 'scope' => 'header', 'group' => 'JS_THEME'));

    $google_map_latitude=theme_get_setting('google_map_latitude');
    $google_map_longitude=theme_get_setting('google_map_longitude');
    $google_map_zoom=theme_get_setting('google_map_zoom');
    $google_map_canvas=theme_get_setting('google_map_canvas');
    $google_map_show=theme_get_setting('google_map_show');
    $google_map_hide=theme_get_setting('google_map_hide');

    drupal_add_js('jQuery(document).ready(function($) {

    if ($("#'.$google_map_canvas.'").length) {
        myLatlng = new google.maps.LatLng('.$google_map_latitude.', '.$google_map_longitude.');
        myZoom = '.$google_map_zoom.';

        function initialize() {
          var mapOptions = {
            zoom: myZoom,
            mapTypeId: google.maps.MapTypeId.ROADMAP,
            center: myLatlng,
            scrollwheel: false
          };

          map = new google.maps.Map(document.getElementById("'.$google_map_canvas.'"),mapOptions);

          marker = new google.maps.Marker({
            map:map,
            draggable:true,
            position: myLatlng
          });

          google.maps.event.addDomListener(window, "resize", function() {
            map.setCenter(myLatlng);
          });
        }
        google.maps.event.addDomListener(window, "load", initialize);
      }

      $("#mapswitch").change(function(){
        if ($(this).is(":checked")) {
          $("#'.$google_map_canvas.'").show();
          google.maps.event.trigger(map, "resize");
          map.setCenter(myLatlng);
          map.setZoom(myZoom);
        } else {
          $("#'.$google_map_canvas.'").slideUp();
        }
      });

    });',
    array('type' => 'inline', 'scope' => 'header'));

    /**
     * Add Javascript
     */
    drupal_add_js('
    function hideMap(){
      jQuery("#map-anchor").html("<a href=\"javascript:showMap()\">'.$google_map_show.'</a>");
      jQuery("#map-canvas").hide();
    }

    function showMap() {
      jQuery("#map-anchor").html("<a href=\"javascript:hideMap()\">'.$google_map_hide.'</a>");
      jQuery("#map-canvas").show();
      google.maps.event.trigger(map, "resize");
      map.setCenter(myLatlng);
      map.setZoom(myZoom);
    }',
    array('type' => 'inline', 'scope' => 'header'));
    //EOF:Javascript

  }



  if (!empty($variables['page']['sidebar_offcanvas'])) {
    drupal_add_js(drupal_get_path('theme', 'portfolioplus') . '/js/jasny-bootstrap/js/jasny-bootstrap.js');
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/js/jasny-bootstrap/css/jasny-bootstrap.css');

    drupal_add_js('jQuery(document).ready(function($) {
      $("#offcanvas-sidebar.navmenu").offcanvas({
        disableScrolling: false,
        canvas: "body",
        toggle: false
      });
      $(window).scroll(function() {
        if($(this).scrollTop() != 0) {
          $(".offcanvas-trigger").addClass("scrolled");
        } else {
          $(".offcanvas-trigger").removeClass("scrolled");
        }
      });

      $("#toTop").click(function() {
        $("body,html").animate({scrollTop:0},800);
      });
    });',
    array('type' => 'inline', 'scope' => 'header'));
  }




}

/**
 * Override or insert variables into the html template.
 */
function portfolioplus_process_html(&$vars) {

  $classes = explode(' ', $vars['classes']);
  $classes[] = theme_get_setting('sitename_font_family');
  $classes[] = theme_get_setting('slogan_font_family');
  $classes[] = theme_get_setting('headings_font_family');
  $classes[] = theme_get_setting('paragraph_font_family');
  $classes[] = theme_get_setting('monospaced_font_family');
  $classes[] =  theme_get_setting('offcanvas_layout_side')."-enabled";
  $vars['classes'] = trim(implode(' ', $classes));

}

/**
 * Preprocess variables for page template.
 */
function portfolioplus_preprocess_page(&$variables) {

  $variables['offcanvas_side'] = theme_get_setting('offcanvas_layout_side');
  $variables['header_layout_mode'] = theme_get_setting('header_layout_mode');
  $variables['highlighted_top_layout_mode'] = theme_get_setting('highlighted_top_layout_mode');
  $variables['parallax_layout_mode'] = theme_get_setting('parallax_layout_mode');
  $variables['highlighted_layout_mode'] = theme_get_setting('highlighted_layout_mode');

  $sidebar_first = $variables['page']['sidebar_first'];
  $sidebar_second = $variables['page']['sidebar_second'];
  $footer_first = $variables['page']['footer_first'];
  $footer_second = $variables['page']['footer_second'];
  $footer_third = $variables['page']['footer_third'];
  $footer_fourth = $variables['page']['footer_fourth'];
  $footer_bottom_first = $variables['page']['footer_bottom_first'];
  $footer_bottom_second = $variables['page']['footer'];
  $footer_bottom_third = $variables['page']['footer_bottom_third'];
  $subfooter_right = $variables['page']['sub_footer_first'];
  $subfooter_left = $variables['page']['sub_footer_second'];

  /**
   * Insert variables into the page template.
   */
  if (isset($variables['node']) && $variables['node']->type != 'page' ) {

    if($sidebar_first && $sidebar_second) {
      $variables['main_grid_class'] = 'col-md-6';
      $variables['sidebar_grid_class'] = 'col-md-3';
    } elseif ($sidebar_first && !$sidebar_second) {
      $variables['main_grid_class'] = 'col-md-8 col-lg-offset-1';
      $variables['sidebar_grid_class'] = 'col-md-4 col-lg-3';
    } elseif (!$sidebar_first && $sidebar_second) {
      $variables['main_grid_class'] = 'col-md-8';
      $variables['sidebar_grid_class'] = 'col-md-4 col-lg-3 col-lg-offset-1';
    } else {
      $variables['main_grid_class'] = 'col-md-8 col-md-offset-2';
      $variables['sidebar_grid_class'] = '';
    }

  } else {

    if($sidebar_first && $sidebar_second) {
      $variables['main_grid_class'] = 'col-md-6';
      $variables['sidebar_grid_class'] = 'col-md-3';
    } elseif ($sidebar_first && !$sidebar_second) {
      $variables['main_grid_class'] = 'col-md-8 col-lg-offset-1';
      $variables['sidebar_grid_class'] = 'col-md-4 col-lg-3';
    } elseif (!$sidebar_first && $sidebar_second) {
      $variables['main_grid_class'] = 'col-md-8';
      $variables['sidebar_grid_class'] = 'col-md-4 col-lg-3 col-lg-offset-1';
    } else {
      $variables['main_grid_class'] = 'col-md-12';
      $variables['sidebar_grid_class'] = '';
    }

  }

  /*Footer Layout*/
  if ($footer_first && $footer_second && $footer_third && $footer_fourth) {
    $variables['footer_grid_class'] = 'col-sm-6 col-md-3';
  } elseif ((!$footer_first && $footer_second && $footer_third && $footer_fourth) || ($footer_first && !$footer_second && $footer_third && $footer_fourth)
  || ($footer_first && $footer_second && !$footer_third && $footer_fourth) || ($footer_first && $footer_second && $footer_third && !$footer_fourth)) {
    $variables['footer_grid_class'] = 'col-sm-4';
  } elseif ((!$footer_first && !$footer_second && $footer_third && $footer_fourth) || (!$footer_first && $footer_second && !$footer_third && $footer_fourth)
  || (!$footer_first && $footer_second && $footer_third && !$footer_fourth) || ($footer_first && !$footer_second && !$footer_third && $footer_fourth)
  || ($footer_first && !$footer_second && $footer_third && !$footer_fourth) || ($footer_first && $footer_second && !$footer_third && !$footer_fourth)) {
    $variables['footer_grid_class'] = 'col-sm-6';
  } else {
    $variables['footer_grid_class'] = 'col-sm-12';
  }

  if($footer_bottom_first && $footer_bottom_second && $footer_bottom_third) {
    $variables['footer_bottom_first_grid_class'] = 'col-md-3';
    $variables['footer_bottom_second_grid_class'] = 'col-md-6';
    $variables['footer_bottom_third_grid_class'] = 'col-md-3';
  } elseif ($footer_bottom_first && $footer_bottom_second && !$footer_bottom_third) {
    $variables['footer_bottom_first_grid_class'] = 'col-md-4';
    $variables['footer_bottom_second_grid_class'] = 'col-md-8';
    $variables['footer_bottom_third_grid_class'] = '';
  } elseif ($footer_bottom_first && !$footer_bottom_second && $footer_bottom_third) {
    $variables['footer_bottom_first_grid_class'] = 'col-md-6';
    $variables['footer_bottom_second_grid_class'] = '';
    $variables['footer_bottom_third_grid_class'] = 'col-md-6';
  } elseif (!$footer_bottom_first && $footer_bottom_second && $footer_bottom_third) {
    $variables['footer_bottom_first_grid_class'] = '';
    $variables['footer_bottom_second_grid_class'] = 'col-md-8';
    $variables['footer_bottom_third_grid_class'] = 'col-md-4';
  } else {
    $variables['footer_bottom_first_grid_class'] = 'col-md-12';
    $variables['footer_bottom_second_grid_class'] = 'col-md-12';
    $variables['footer_bottom_third_grid_class'] = 'col-md-12';
  }

}

/**
* Implements hook_preprocess_maintenance_page().
*/
function portfolioplus_preprocess_maintenance_page(&$variables) {

  $color_scheme = theme_get_setting('color_scheme');
  if ($color_scheme != 'default') {
    drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/style-' .$color_scheme. '.css', array('group' => CSS_THEME, 'type' => 'file'));
  }

  drupal_add_css(drupal_get_path('theme', 'portfolioplus') . '/fonts/lato-font.css', array('group' => CSS_THEME, 'type' => 'file'));

}

function portfolioplus_page_alter($page) {

  $mobileoptimized = array(
    '#type' => 'html_tag',
    '#tag' => 'meta',
    '#attributes' => array(
    'name' =>  'MobileOptimized',
    'content' =>  'width'
    )
  );
  $handheldfriendly = array(
    '#type' => 'html_tag',
    '#tag' => 'meta',
    '#attributes' => array(
    'name' =>  'HandheldFriendly',
    'content' =>  'true'
    )
  );
  $viewport = array(
    '#type' => 'html_tag',
    '#tag' => 'meta',
    '#attributes' => array(
    'name' =>  'viewport',
    'content' =>  'width=device-width, initial-scale=1'
    )
  );
  drupal_add_html_head($mobileoptimized, 'MobileOptimized');
  drupal_add_html_head($handheldfriendly, 'HandheldFriendly');
  drupal_add_html_head($viewport, 'viewport');

}

function portfolioplus_form_alter(&$form, &$form_state, $form_id) {

  if ($form_id == 'search_block_form') {
    unset($form['search_block_form']['#title']);
    $form['search_block_form']['#title_display'] = 'invisible';
    $form_default = t('Enter terms then hit Search...');
    $form['search_block_form']['#default_value'] = $form_default;

    $form['actions']['submit']['#attributes']['value'][] = '';

    $form['search_block_form']['#attributes'] = array('onblur' => "if (this.value == '') {this.value = '{$form_default}';}", 'onfocus' => "if (this.value == '{$form_default}') {this.value = '';}" );
  }

}

?>
